@@ -6,8 +6,8 @@
 
       Jane Street Holding, LLC
       Author: Markus Mottl
-      email: mmottl\@janestcapital.com
-      WWW: http://www.janestcapital.com/ocaml
+      email: mmottl\@janestreet.com
+      WWW: http://www.janestreet.com/ocaml
 
    This file is derived from file "pa_tywith.ml" of version 0.45 of the
    library "Tywith".
@@ -1219,7 +1219,7 @@ module Generate_bin_read = struct
                 let err_pos4 =
                   Bin_prot.Unsafe_common.dealloc_sptr_ptr buf sptr_ptr
                 in
-                let err_pos = err_pos4 - 4 in
+                let err_pos = Pervasives.(-) err_pos4 4 in
                 Bin_prot.Common.raise_read_error err err_pos
             | Bin_prot.Unsafe_read_c.Error err ->
                 let err_pos =
@@ -1239,7 +1239,7 @@ module Generate_bin_read = struct
                 let err_pos4 =
                   Bin_prot.Unsafe_common.dealloc_sptr_ptr buf sptr_ptr
                 in
-                let err_pos = err_pos4 - 4 in
+                let err_pos = Pervasives.(-) err_pos4 4 in
                 let err =
                   Bin_prot.Common.ReadError.Variant $str:full_type_name$
                 in
