@@ -5,8 +5,8 @@
 
       Jane Street Holding, LLC
       Author: Markus Mottl
-      email: mmottl\@janestcapital.com
-      WWW: http://www.janestcapital.com/ocaml
+      email: mmottl\@janestreet.com
+      WWW: http://www.janestreet.com/ocaml
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
