@@ -208,6 +208,11 @@ module type Reader_spec = sig
   val bin_read_variant_tag : [> ] reader
   val bin_read_int_64bit : int reader
   val bin_read_int64_bits : int64 reader
+  val bin_read_network16_int : int reader
+  val bin_read_network32_int : int reader
+  val bin_read_network32_int32 : int32 reader
+  val bin_read_network64_int : int reader
+  val bin_read_network64_int64 : int64 reader
 end
 
 module type Writer_spec = sig
@@ -242,6 +247,11 @@ module type Writer_spec = sig
   val bin_write_variant_tag : [> ] writer
   val bin_write_int_64bit : int writer
   val bin_write_int64_bits : int64 writer
+  val bin_write_network16_int : int writer
+  val bin_write_network32_int : int writer
+  val bin_write_network32_int32 : int32 writer
+  val bin_write_network64_int : int writer
+  val bin_write_network64_int64 : int64 writer
 end
 
 module Make (Spec : SPEC) (Read : Reader_spec) (Write : Writer_spec) = struct
@@ -893,6 +903,66 @@ module Make (Spec : SPEC) (Read : Reader_spec) (Write : Writer_spec) = struct
             "Int_overflow (negative)" @? expect_read_error Int_overflow 0 (fun () ->
               Read.bin_read_int_64bit bad_buf_min ~pos_ref:(ref 0));
           );
+
+        "network16_int" >::
+          (fun () ->
+            check_all 2 "network16_int"
+              Read.bin_read_network16_int
+              Write.bin_write_network16_int
+              [
+                (* No negative numbers - ambiguous on 64bit platforms *)
+                (0, "0", 2);
+                (1, "1", 2);
+              ];
+          );
+
+        "network32_int" >::
+          (fun () ->
+            check_all 4 "network32_int"
+              Read.bin_read_network32_int
+              Write.bin_write_network32_int
+              [
+                (* No negative numbers - ambiguous on 64bit platforms *)
+                (0, "0", 4);
+                (1, "1", 4);
+              ];
+          );
+
+        "network32_int32" >::
+          (fun () ->
+            check_all 4 "network32_int32"
+              Read.bin_read_network32_int32
+              Write.bin_write_network32_int32
+              [
+                (-1l, "-1", 4);
+                (0l, "0", 4);
+                (1l, "1", 4);
+              ];
+          );
+
+        "network64_int" >::
+          (fun () ->
+            check_all 8 "network64_int"
+              Read.bin_read_network64_int
+              Write.bin_write_network64_int
+              [
+                (-1, "-1", 8);
+                (0, "0", 8);
+                (1, "1", 8);
+              ];
+          );
+
+        "network64_int64" >::
+          (fun () ->
+            check_all 8 "network64_int64"
+              Read.bin_read_network64_int64
+              Write.bin_write_network64_int64
+              [
+                (-1L, "-1", 8);
+                (0L, "0", 8);
+                (1L, "1", 8);
+              ];
+          );
       ]
 end
 
